@@ -813,7 +813,8 @@ def possibilidade_desconectar_e_fechar_janela():
                                                 ).key_down(Keys.ARROW_DOWN
                                                         ).key_down(Keys.ARROW_DOWN
                                                                 ).send_keys(Keys.ENTER
-                                                                        ).perform()
+                                                                        ).send_keys(Keys.ENTER
+                                                                                    ).perform()
     
     t.sleep(1)
     # xpath2
@@ -960,6 +961,20 @@ def buscar_contatos_não_lidos():
 
 
 
+def nome_usuario():
+    xpath1 = '//*[@id="app"]/div/div/div[3]/header/div[1]/div/img'
+    xpath2 = '//*[@id="app"]/div/div/div[2]/div[1]/span/div/span/div/div/div[2]/div[2]/div/div[1]/div/div[2]'
+    xpath3 = '//*[@id="app"]/div/div/div[2]/div[1]/span/div/span/div/header/div/div[1]/div/span'
+    
+    drive.find_element(By.XPATH, xpath1).click()
+    nome = drive.find_element(By.XPATH, xpath2).text
+    drive.find_element(By.XPATH, xpath3).click()
+    
+    return nome
+#
+
+
+
 def lista_ultimas_mensagens_recebidas_de_contatos(quantidade: int = 1):
 
     '''
